@@ -47,10 +47,10 @@ void HLCmdLineApp::printVersionInfo()
 {
     cout << "\n highlight version "
          << HIGHLIGHT_VERSION
-         << "\n Copyright (C) 2002-2011 Andre Simon <andre.simon1 at gmx.de>"
+         << "\n Copyright (C) 2002-2012 Andre Simon <andre.simon1 at gmx.de>"
          << "\n\n Argparser class"
          << "\n Copyright (C) 2006-2008 Antonio Diaz Diaz <ant_diaz at teleline.es>"
-         << "\n\n Artistic Style Classes (2.02)"
+         << "\n\n Artistic Style Classes (2.02.1)"
          << "\n Copyright (C) 2006-2011 by Jim Pattee <jimp03 at email.com>"
          << "\n Copyright (C) 1998-2002 by Tal Davidson"
          << "\n\n Diluculum Lua wrapper (0.5.3)"
@@ -227,7 +227,12 @@ void HLCmdLineApp::printConfigInfo ( const string& configFile )
 string HLCmdLineApp::getFileSuffix ( const string &fileName )
 {
     size_t ptPos=fileName.rfind ( "." );
-    return ( ptPos == string::npos ) ? "" : fileName.substr ( ptPos+1, fileName.length() );
+    size_t psPos = fileName.rfind ( Platform::pathSeparator );
+
+    if ( ptPos > psPos && ptPos != string::npos )
+        return fileName.substr ( ptPos+1, fileName.length() );
+    else
+        return "";
 }
 
 bool HLCmdLineApp::loadFileTypeConfig ( const string& name, StringMap* extMap, StringMap* shebangMap )
@@ -346,7 +351,8 @@ string HLCmdLineApp::analyzeFile ( const string& file )
     StringMap::iterator it;
     for ( it=scriptShebangs.begin(); it!=scriptShebangs.end();it++ )
     {
-        if ( Pattern::matches ( it->first, firstLine ) ) return it->second;
+        pair<string, int> matched = Pattern::findNthMatch ( it->first, firstLine, 0 );
+        if ( matched.second >= 0 ) return it->second;
     }
     return "";
 }
@@ -355,11 +361,12 @@ string HLCmdLineApp::guessFileType ( const string& suffix, const string &inputFi
 {
     if (suffix.empty()) return analyzeFile ( inputFile );
     string lcSuffix = StringTools::change_case ( suffix );
-    string fileType = ( extensions.count ( lcSuffix ) ) ? extensions[lcSuffix] : lcSuffix ;
-    if ( !fileType.empty() ) return fileType;
-    return "";
+    return ( extensions.count ( lcSuffix ) ) ? extensions[lcSuffix] : lcSuffix ;
+   // if ( !fileType.empty() ) return fileType;
+   // return "";
 }
 
+
 int HLCmdLineApp::run ( const int argc, const char*argv[] )
 {
     CmdLineOptions options ( argc, argv );
