@@ -29,9 +29,7 @@ along with Highlight.  If not, see <http://www.gnu.org/licenses/>.
 #include <iomanip>
 #include <cassert>
 
-//#include "./dirstream0.4/dirstream.h"
 #include "cmdlineoptions.h"
-#include "configurationreader.h"
 #include "codegenerator.h"
 #include "help.h"
 #include "datadir.h"
@@ -93,7 +91,7 @@ class HLCmdLineApp
 		    \param  lang language definition
 		    \param langDefPath path to language definition
 		*/
-		void printDebugInfo ( const highlight::LanguageDefinition &lang,
+		void printDebugInfo ( const highlight::SyntaxReader *lang,
 		                      const string &langDefPath );
 
 		string getFileSuffix ( const string &fileName );
