@@ -2,7 +2,7 @@
                           stringtools.cpp  -  description
                              -------------------
     begin                : Mon Dec 10 2001
-    copyright            : (C) 2001 by Andre Simon
+    copyright            : (C) 2001-2010 by Andre Simon
     email                : andre.simon1@gmx.de
  ***************************************************************************/
 
@@ -74,15 +74,17 @@ namespace StringTools
 		return value.substr ( 0, where + 1 );
 	}
 
-	string getParantheseVal ( const string &s )
+	string trim(const string& s)
 	{
-		string::size_type openPos=s.find ( '(' );
-		string::size_type closePos=s.rfind ( ')' );
-		if ( openPos ==string::npos || closePos==string::npos )
-		{
-			return string();
-		}
-		return s.substr ( openPos+1, closePos-openPos-1 );
+	  string str(s);
+	  string::size_type pos = str.find_last_not_of(' ');
+	  if(pos != string::npos) {
+	    str.erase(pos + 1);
+	    pos = str.find_first_not_of(' ');
+	    if(pos != string::npos) str.erase(0, pos);
+	  }
+	  else str.erase(str.begin(), str.end());
+	  return str;
 	}
 
 	vector<string> splitString ( const string& s, unsigned char delim )
@@ -108,4 +110,25 @@ namespace StringTools
 		return results;
 	}
 
+        int calcWeight(const string&s){
+ 		int sum=0;
+		for (unsigned int i=0; i<s.size();i++){
+			sum+=(i%2)? int(s[i])*3 : int(s[i]);
+		}
+		return sum;
+	}
+
+	string getPathAcronym(const string&path, char delim) {
+	  string acronym;
+	  size_t pos=0;
+	  while ((pos=path.find(delim, pos))!=string::npos){
+	    pos++;
+	    if (pos<path.size() && path[pos]!=delim) {
+	      acronym+= path[pos];
+	    }
+	  }
+	  if(!acronym.empty()) acronym.replace(acronym.end()-1, acronym.end(), "_");
+	  return acronym;
+      }
+
 }
