@@ -455,8 +455,13 @@ bool MainWindow::loadFileTypeConfig(StringMap* extMap, StringMap* shebangMap) {
     string firstLine;
     getline (inFile, firstLine);
     StringMap::iterator it;
-    for (it=shebangs.begin(); it!=shebangs.end();it++){
+    /*for (it=shebangs.begin(); it!=shebangs.end();it++){
        if (Pattern::matches(it->first, firstLine)) return it->second;
+    }*/
+    for ( it=shebangs.begin(); it!=shebangs.end();it++ )
+    {
+        pair<string, int> matched = Pattern::findNthMatch ( it->first, firstLine, 0 );
+        if ( matched.second >= 0 ) return it->second;
     }
     return "";
 }
@@ -476,6 +481,18 @@ string MainWindow::getFileSuffix(const string& fileName)
                                         fileName.length());
 }
 
+/*
+string MainWindow::getFileSuffix ( const string &fileName )
+{
+    size_t ptPos=fileName.rfind ( "." );
+    size_t psPos = fileName.rfind ( Platform::pathSeparator );
+
+    if ( ptPos > psPos && ptPos != string::npos )
+        return fileName.substr ( ptPos+1, fileName.length() );
+    else
+        return "";
+}
+*/
 void MainWindow::on_action_Exit_triggered()
 {
     this->close();
@@ -486,7 +503,7 @@ void MainWindow::on_action_About_Highlight_triggered()
      QMessageBox::about( this, "About Highlight",
                          QString("Highlight is a code to formatted text converter.\n\n"
                          "Highlight GUI %1\n"
-                         "(C) 2002-2011 Andre Simon <andre.simon1 at gmx.de>\n\n"
+                         "(C) 2002-2012 Andre Simon <andre.simon1 at gmx.de>\n\n"
                          "Artistic Style Classes\n(C) 1998-2002 Tal Davidson\n"
                          "(C) 2006-2011 Jim Pattee <jimp03 at email.com>\n\n"
                          "Diluculum Lua wrapper\n"
